@@ -3,7 +3,7 @@
 '''
 A library to access Tryton's models like a client.
 '''
-__version__ = "3.8.1"
+__version__ = "4.0.1"
 __all__ = ['Model', 'Wizard', 'Report']
 import sys
 try:
@@ -18,7 +18,6 @@ import threading
 import datetime
 import functools
 from decimal import Decimal
-from types import NoneType
 
 import proteus.config
 
@@ -159,14 +158,14 @@ class BinaryDescriptor(FieldDescriptor):
 class IntegerDescriptor(FieldDescriptor):
 
     def __set__(self, instance, value):
-        assert isinstance(value, (int, long, NoneType))
+        assert isinstance(value, (int, long, type(None)))
         super(IntegerDescriptor, self).__set__(instance, value)
 
 
 class FloatDescriptor(FieldDescriptor):
 
     def __set__(self, instance, value):
-        assert isinstance(value, (int, long, float, Decimal, NoneType))
+        assert isinstance(value, (int, long, float, Decimal, type(None)))
         if value is not None:
             value = float(value)
         super(FloatDescriptor, self).__set__(instance, value)
@@ -175,7 +174,7 @@ class FloatDescriptor(FieldDescriptor):
 class NumericDescriptor(FieldDescriptor):
 
     def __set__(self, instance, value):
-        assert isinstance(value, (NoneType, Decimal))
+        assert isinstance(value, (type(None), Decimal))
         # TODO add digits validation
         super(NumericDescriptor, self).__set__(instance, value)
 
@@ -192,7 +191,7 @@ class ReferenceDescriptor(FieldDescriptor):
         return value
 
     def __set__(self, instance, value):
-        assert isinstance(value, (Model, NoneType, basestring))
+        assert isinstance(value, (Model, type(None), basestring))
         if isinstance(value, basestring):
             assert value.startswith(',')
         elif isinstance(value, Model):
@@ -254,7 +253,7 @@ class Many2OneDescriptor(FieldDescriptor):
         return value
 
     def __set__(self, instance, value):
-        assert isinstance(value, (Model, NoneType))
+        assert isinstance(value, (Model, type(None)))
         if value:
             assert value._config == instance._config
         super(Many2OneDescriptor, self).__set__(instance, value)
@@ -661,7 +660,7 @@ class Model(object):
     @classmethod
     def get(cls, name, config=None):
         'Get a class for the named Model'
-        if isinstance(name, unicode):
+        if (bytes == str) and isinstance(name, unicode):
             name = name.encode('utf-8')
 
         class Spam(Model):
@@ -692,14 +691,17 @@ class Model(object):
                 repr(self._config), self.id)
     __repr__.__doc__ = object.__repr__.__doc__
 
-    def __cmp__(self, other):
-        'Compare with other'
+    def __eq__(self, other):
         if isinstance(other, Model):
-            return cmp((self.__class__.__name__, self.id),
+            return ((self.__class__.__name__, self.id) ==
                 (other.__class__.__name__, other.id))
-        if isinstance(other, (bool, NoneType)):
-            return 1
-        raise NotImplementedError
+        return NotImplemented
+
+    def __ne__(self, other):
+        return not self == other
+
+    def __hash__(self):
+        return hash(self.__class__.__name__) ^ hash(self.id)
 
     @property
     def id(self):
@@ -1074,7 +1076,7 @@ class Wizard(object):
                 ctx['active_ids'] = None
                 ctx['active_model'] = None
             if self.action:
-                ctx['action_id'] = self.action.id
+                ctx['action_id'] = self.action['id']
             else:
                 ctx['action_id'] = None
 
@@ -1096,7 +1098,6 @@ class Wizard(object):
                 self.form._default_set(view['defaults'])
                 self.states = [b['state'] for b in view['buttons']]
                 self.form_state = view['state']
-                return
             else:
                 self.state = self.end_state
 
@@ -1107,6 +1108,9 @@ class Wizard(object):
                 if proteus_action:
                     self.actions.append(proteus_action)
 
+            if 'view' in result:
+                return
+
         if self.state == self.end_state:
             self._proxy.delete(self.session_id, self._config.context)
             if self.models:
